@@ -1,6 +1,3 @@
-
-# i_valid_scale()
-
 test_that("i_valid_scale: correct return values", {
   testData <- data.frame(
     validScale = i_labelled(1:3, scale = c("nominal")),
@@ -16,3 +13,11 @@ test_that("i_valid_scale: correct return values", {
   expect_false(i_valid_scale(testData$missingScale))
   expect_equal(i_valid_scale(testData), retList)
 })
+
+test_that("i_scale: remove scale by providing NULL value", {
+  x <- i_labelled(iris$Species, scale = "nominal")
+  x <- i_scale(x = x, scale = NULL)
+  expect_null(attr(x, "scale", exact = TRUE))
+})
+
+
